==> xmgfv1.9.1.tar.gz: xmgf/inc/Parse.h <==
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */
extern int      SelectColours;
extern int      SelectPoints;
extern int      SelectLabels;
extern int      Sorting;
extern int      Centroid;
extern int      DoubleBuff;
extern int      BackFace;
extern int      Axis;
extern int      Axis_Size;
extern int	DefaultAxisSize;
extern int	DefaultAnimSpeed;
extern int      AxisLabel;
extern int      DefaultResolution;
extern int      BackDropImage;
extern int      ExpandImage;
extern int      Origin;
extern double    UserScaleFactor;
extern int      DefaultLineStyle;
extern int      DefaultFillStyle;
extern int      DefaultLineWidth;
extern int      DefaultTessLevel;
extern int      DefaultPointSize;
extern int	DefaultPointType;
extern int      PSOrientation;
extern int      PSColour;
extern int      DefaultMaxDisp;
extern int      BackDropWidth;
extern int      BackDropHeight;
extern int      OrBackDropWidth;
extern int      OrBackDropHeight;
extern int      polydiv;
extern int      FillPolys;
extern int      Oldviewtype;
extern int      DepthCueing;
extern int      RotateGuide;
extern int      FixateType;
extern int      ScaleObectType;
extern int      DefaultARThetaStep;
extern int      DefaultARPhiStep;
extern int      DefaultARGammaStep;
extern int      ARThetaStep;
extern int      ARPhiStep;
extern int      ARGammaStep;
extern int      ARScale;
extern int      BackGroundColour;
extern int	AutoCommand;
extern int      AutoRotateFlag;
extern char 	commandfile[100];
extern char 	controlfile[100];
extern int	GFColours;
extern int 	AxisType;
extern int      AxisColour;
extern int      OrthoGraphicProj;
extern int 	TwoDimSettings;
extern int	ICONPANEL;
extern int	MAINPANEL;
extern int 	OutLineColour;
extern int 	OutLine;
extern int 	DitherFill;


#ifndef _NO_PROTO
void             ParseCommandLine (int argc, char **argv);
#else
void             ParseCommandLine ();
#endif

==> xmgfv2.4.tar.gz: xmgf/inc/Parse.h <==
/*static char sccsid[]="@(#)%E% P.Hoad@ee.surrey.ac.uk %I% %M%";*/
/*
 * Copyright (C) 1992, 1993, Paul D. Hoad This file is part of the Xmgf
 * Software. For conditions of distribution and use, see the accompanying
 * README file.
 * 
 * Vision Speech and Signal Processing Group . Dept. of Electronic Engineering.
 * University of Surrey. Guildford, Surrey. England. Phone: +44 483 300800
 * Ext 2753 Email: P.Hoad@ee.surrey.ac.uk
 */
extern int      SelectColours;
extern int      SelectPoints;
extern int      SelectLabels;
extern int      Sorting;
extern int      Centroid;
extern int      DoubleBuff;
extern int      BackFace;
extern int      Axis;
extern int      Axis_Size;
extern int	DefaultAxisSize;
extern int	DefaultAnimSpeed;
extern int      AxisLabel;
extern int      DefaultResolution;
extern int      BackDropImage;
extern int      ExpandImage;
extern int      Origin;
extern double    UserScaleFactor;
extern int      DefaultLineStyle;
extern int      DefaultFillStyle;
extern int      DefaultLineWidth;
extern int      DefaultTessLevel;
extern int      DefaultPointSize;
extern int	DefaultPointType;
extern int      PSOrientation;
extern int      PSColour;
extern int      DefaultMaxDisp;
extern int      BackDropWidth;
extern int      BackDropHeight;
extern int      OrBackDropWidth;
extern int      OrBackDropHeight;
extern int      polydiv;
extern int      FillPolys;
extern int      Oldviewtype;
extern int      DepthCueing;
extern int      PointCueing;
extern int      RotateGuide;
extern int      FixateType;
extern int      ScaleObectType;
extern int      DefaultARThetaStep;
extern int      DefaultARPhiStep;
extern int      DefaultARGammaStep;
extern int      ARThetaStep;
extern int      ARPhiStep;
extern int      ARGammaStep;
extern int      ARScale;
extern int      BackGroundColour;
extern int	AutoCommand;
extern int      AutoRotateFlag;
extern char 	commandfile[100];
extern char 	controlfile[100];
extern int	GFColours;
extern int 	AxisType;
extern int      AxisColour;
extern int      OrthoGraphicProj;
extern int 	TwoDimSettings;
extern int	ICONPANEL;
extern int	MAINPANEL;
extern int 	OutLineColour;
extern int 	OutLine;
extern int 	DitherFill;
extern int 	ScrClrThes;
extern int	RedBlue;
/* New after 2.0 */
extern int      HaloedColor;
extern int      LeftEyeColour;
extern int      RightEyeColour;
extern int      TranslationStep;


#ifndef _NO_PROTO
void             ParseCommandLine (int argc, char **argv);
#else
void             ParseCommandLine ();
#endif
